@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 our $schema = ['dirname' => {
     summary => 'Directory name, default to current directory',
@@ -42,7 +42,7 @@ Sah::Schema::dirname::default_curdir - Directory name, default to current direct
 
 =head1 VERSION
 
-This document describes version 0.021 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
+This document describes version 0.022 of Sah::Schema::dirname::default_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 SYNOPSIS
 
@@ -175,6 +175,10 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Path>.
 
+=head1 SEE ALSO
+
+L<Sah::Schema::dirname::default_curdir_abs>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
