@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.021 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
+This document describes version 0.022 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 DESCRIPTION
 
@@ -85,6 +85,17 @@ non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by
 default.
 
 
+=item * L<dirname::default_curdir_abs|Sah::Schema::dirname::default_curdir_abs>
+
+Directory name, default to current directory (absolutified).
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. a
+C<delete-files-in> script). It is safer to use this schema to perform a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by
+default.
+
+
 =item * L<dirname::exists|Sah::Schema::dirname::exists>
 
 Directory name, must exist on filesystem.
